@@ -1,9 +1,9 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from __future__ import annotations
 
 from typing import Any
-from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
+
+from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
 
 
 class ModelRegistry(NamespacedResource):
